# GuardBench: A Large-Scale Benchmark for Guardrail Models

## Introduction
GuardBench is a Python library for guardrail models evaluation.  
It provides a common interface to 40 evaluation datasets for guardrail models.  
GuardBench takes care of downloading datasets and formatting them in a standardized format.

You can find the list of datasets in docs/datasets.md.

## Requirements
```bash
python>=3.10
```

## Installation 
Create a Python environment and install the packages listed in `requirements.txt`.

## Reproduce experiments
NOTE: reproducing our experiments will require at least an RTX 3090 and a few days of computation. Code was tested only on Ubuntu.

To reproduce the experiments in our paper:
1. Consult docs/get_datasets.md
2. Copy the datasets in the source code folder.
3. Run the commands reported below. You can change the default device (cuda), datasets (all), and batch size with the following flags: `--device`, `--datasets`, `--batch_size`. Defaults: `--device cuda --datasets all`. `--batch_size` is different for each model.
4. To inspect the results use the `inspect_results.ipynb` notebook.

```bash
python -m scripts.detoxify 
python -m scripts.llama_guard_2
python -m scripts.llama_guard_defensive
python -m scripts.llama_guard_permissive
python -m scripts.llama_guard
python -m scripts.md_judge
python -m scripts.mistral_plus
python -m scripts.mistral
python -m scripts.toxic_chat_t5
python -m scripts.toxigen_hatebert
python -m scripts.toxigen_roberta
```

## Usage
- Follow our tutorial in docs/llama_guard.md to learn how to benchmark Llama Guard (https://arxiv.org/pdf/2312.06674) with GuardBench.
- More examples are available in the scripts folder.

## Documentation
Browse the docs folder for more details.